##########################################################################################
#Title: Replication code for "The role of market frictions in demand for prepaid electricity"
#Author: Megan Lang
#Date started: February 22, 2025
##########################################################################################

library(ggplot2)
library(readxl)
library(dplyr)
library(xtable)
library(lfe)
library(stargazer)
library(AER)
library(stringr)
library(pscl)
library(foreign)
library(boot)
library(lubridate)
renv::snapshot()

renv::restore(lockfile = "renv.lock", prompt = FALSE)
#Date of final data pull
date <- as.Date("2020-02-19")
file.date <- "2020 02 19"


load("UR.Rda")
load("Cur_Cust.Rda")
load("pmt_panel.Rda")
load("ids.Rda")
load("dr_all.Rda")
load("ur_enable2.Rda")
load("ldf_full.Rda")

phone.sur <- read.csv("phone_admin_linked.csv") #2019 phone survey linked with admin data

ur1 <- read.csv("2020 02 19 UR 1.csv")
ur2 <- read.csv("2020 02 19 UR 2.csv")
ur.raw <- left_join(ur2, ur1)

##########################################################################################
# Functions  
##########################################################################################
####Get control means####
cmeans <- function(outcome){
  w1 <- length(cur.cust$customer.id[which(cur.cust$bin1==1 & cur.cust$treated==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0)])
  w2 <- length(cur.cust$customer.id[which(cur.cust$bin2==1 & cur.cust$treated==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0)])
  w3 <- length(cur.cust$customer.id[which(cur.cust$bin3==1 & cur.cust$treated==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0)])
  w4 <- length(cur.cust$customer.id[which(cur.cust$bin4==1 & cur.cust$treated==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0)])
  
  w1lsd <- length(cur.cust$customer.id[which(cur.cust$bin1==1 & cur.cust$treated==0 & cur.cust$highSD==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==0)])
  w2lsd <- length(cur.cust$customer.id[which(cur.cust$bin2==1 & cur.cust$treated==0 & cur.cust$highSD==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==0)])
  w3lsd <- length(cur.cust$customer.id[which(cur.cust$bin3==1 & cur.cust$treated==0 & cur.cust$highSD==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==0)])
  w4lsd <- length(cur.cust$customer.id[which(cur.cust$bin4==1 & cur.cust$treated==0 & cur.cust$highSD==0)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==0)])
  
  w1hsd <- length(cur.cust$customer.id[which(cur.cust$bin1==1 & cur.cust$treated==0 & cur.cust$highSD==1)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==1)])
  w2hsd <- length(cur.cust$customer.id[which(cur.cust$bin2==1 & cur.cust$treated==0 & cur.cust$highSD==1)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==1)])
  w3hsd <- length(cur.cust$customer.id[which(cur.cust$bin3==1 & cur.cust$treated==0 & cur.cust$highSD==1)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==1)])
  w4hsd <- length(cur.cust$customer.id[which(cur.cust$bin4==1 & cur.cust$treated==0 & cur.cust$highSD==1)])/length(cur.cust$customer.id[which(cur.cust$treated==0 & cur.cust$highSD==1)])
  
  if (outcome=="ur"){
    mean0 <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0)],na.rm=T)
    mean1 <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1)],na.rm=T)
    mean2 <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2)],na.rm=T)
    mean3 <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3)],na.rm=T)
    mean0lsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==0)],na.rm=T)
    mean1lsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==0)],na.rm=T)
    mean2lsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==0)],na.rm=T)
    mean3lsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==0)],na.rm=T)
    mean0hsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==1)],na.rm=T)
    mean1hsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==1)],na.rm=T)
    mean2hsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==1)],na.rm=T)
    mean3hsd <- mean(ur$ur[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==1)],na.rm=T)
    mean <- w1*mean0 + w2*mean1 + w3*mean2 + w4*mean3
    meanlsd <- w1lsd*mean0lsd + w2lsd*mean1lsd + w3lsd*mean2lsd + w4lsd*mean3lsd
    meanhsd <- w1hsd*mean0hsd + w2hsd*mean1hsd + w3hsd*mean2hsd + w4hsd*mean3hsd
  } else if (outcome=="nt"){
    mean0 <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0)],na.rm=T)
    mean1 <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1)],na.rm=T)
    mean2 <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2)],na.rm=T)
    mean3 <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3)],na.rm=T)
    mean0lsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==0)],na.rm=T)
    mean1lsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==0)],na.rm=T)
    mean2lsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==0)],na.rm=T)
    mean3lsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==0)],na.rm=T)
    mean0hsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==1)],na.rm=T)
    mean1hsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==1)],na.rm=T)
    mean2hsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==1)],na.rm=T)
    mean3hsd <- mean(ur$ntrans[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==1)],na.rm=T)
    mean <- w1*mean0 + w2*mean1 + w3*mean2 + w4*mean3
    meanlsd <- w1lsd*mean0lsd + w2lsd*mean1lsd + w3lsd*mean2lsd + w4lsd*mean3lsd
    meanhsd <- w1hsd*mean0hsd + w2hsd*mean1hsd + w3hsd*mean2hsd + w4hsd*mean3hsd
  } else if (outcome=="ts"){
    mean0 <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0)],na.rm=T)
    mean1 <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1)],na.rm=T)
    mean2 <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2)],na.rm=T)
    mean3 <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3)],na.rm=T)
    mean0lsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==0)],na.rm=T)
    mean1lsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==0)],na.rm=T)
    mean2lsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==0)],na.rm=T)
    mean3lsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==0)],na.rm=T)
    mean0hsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==1)],na.rm=T)
    mean1hsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==1)],na.rm=T)
    mean2hsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==1)],na.rm=T)
    mean3hsd <- mean(ur$mean.trans.size[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==1)],na.rm=T)
    mean <- w1*mean0 + w2*mean1 + w3*mean2 + w4*mean3
    meanlsd <- w1lsd*mean0lsd + w2lsd*mean1lsd + w3lsd*mean2lsd + w4lsd*mean3lsd
    meanhsd <- w1hsd*mean0hsd + w2hsd*mean1hsd + w3hsd*mean2hsd + w4hsd*mean3hsd
  } else if (outcome=="wh"){
    mean0 <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0)],na.rm=T)
    mean1 <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1)],na.rm=T)
    mean2 <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2)],na.rm=T)
    mean3 <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3)],na.rm=T)
    mean0lsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==0)],na.rm=T)
    mean1lsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==0)],na.rm=T)
    mean2lsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==0)],na.rm=T)
    mean3lsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==0)],na.rm=T)
    mean0hsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==0 & ur$highSD==1)],na.rm=T)
    mean1hsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==1 & ur$highSD==1)],na.rm=T)
    mean2hsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==2 & ur$highSD==1)],na.rm=T)
    mean3hsd <- mean(ur$wh.out[which(ur$treatment=="control" & ur$month>=4 & ur$util_band==3 & ur$highSD==1)],na.rm=T)
    mean <- w1*mean0 + w2*mean1 + w3*mean2 + w4*mean3
    meanlsd <- w1lsd*mean0lsd + w2lsd*mean1lsd + w3lsd*mean2lsd + w4lsd*mean3lsd
    meanhsd <- w1hsd*mean0hsd + w2hsd*mean1hsd + w3hsd*mean2hsd + w4hsd*mean3hsd
  } else if (outcome=="repo"){
    mean0 <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==0)],na.rm=T)
    mean1 <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==1)],na.rm=T)
    mean2 <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==2)],na.rm=T)
    mean3 <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==3)],na.rm=T)
    mean0lsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==0 & cur.cust$highSD==0)],na.rm=T)
    mean1lsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==1 & cur.cust$highSD==0)],na.rm=T)
    mean2lsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==2 & cur.cust$highSD==0)],na.rm=T)
    mean3lsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==3 & cur.cust$highSD==0)],na.rm=T)
    mean0hsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==0 & cur.cust$highSD==1)],na.rm=T)
    mean1hsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==1 & cur.cust$highSD==1)],na.rm=T)
    mean2hsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==2 & cur.cust$highSD==1)],na.rm=T)
    mean3hsd <- mean(cur.cust$repo[which(cur.cust$treatment=="control" & cur.cust$util_band==3 & cur.cust$highSD==1)],na.rm=T)
    mean <- w1*mean0 + w2*mean1 + w3*mean2 + w4*mean3
    meanlsd <- w1lsd*mean0lsd + w2lsd*mean1lsd + w3lsd*mean2lsd + w4lsd*mean3lsd
    meanhsd <- w1hsd*mean0hsd + w2hsd*mean1hsd + w3hsd*mean2hsd + w4hsd*mean3hsd
  }
  cmeans <- c(mean, mean0, mean1, mean2, mean3, meanlsd, meanhsd)
  bin <- c("Pooled","0%-30%","30%-65%","65%-80%","80%-100%","Low SD","High SD")
  cmeans.df <- as.data.frame(cbind(cmeans, bin))
  colnames(cmeans.df) <- c("Cmean","bin")
  cmeans.df$Cmean <- as.numeric(cmeans.df$Cmean)
  cmeans.df$bin <- factor(cmeans.df$bin, levels = c("Pooled","0%-30%","30%-65%","65%-80%","80%-100%","Low SD","High SD"))
  return(cmeans.df)
  
}
####Generate q-values####
# Note that this is taken directly from Michael Anderson's Stata code, which "generates BKY (2006) sharpened two-stage q-values 
# as described in Anderson (2008), "Multiple Inference and Gender Differences in the Effects of Early Intervention: A Reevaluation 
# of the Abecedarian, Perry Preschool, and Early Training Projects", Journal of the American Statistical Association, 103(484), 1481-1495

# The input to this function should be a dataframe of p-values from a given family, sorted from smallest to largest. The dataframe
# should have columns "Outcome", "coef", "pval". Outcome is the name of the outcome variable. coef is the estimated
# coefficient on the treatment of interest for that outcome. pval is the naive p-value of the estimate.
gen.qvals <- function(df){
  totalpvalues <- as.numeric(length(df$Outcome))
  df <- mutate(df, qval = 1)
  #Set initial condition for the loop to calcualte q-values with 2-step procedure
  qv <- 1
  
  while (qv>0){
    #Generate ranking by p-value
    df <- arrange(df, pval) %>% mutate(rank = row_number())
    # First Stage
    # Generate the adjusted first stage q level we are testing: q' = q/1+q
    qval_adj <- qv/(1+qv)
    #Generate value q'*r/M
    df <- mutate(df, fdr_temp1 = qval_adj*rank/totalpvalues)
    #Generate binary variable checking condition p(r) <= q'*r/M
    df <- mutate(df, reject_temp1 = if_else(fdr_temp1>=pval,1,0))
    #Generate variable containing p-value ranks for all p-values that meet above condition
    df <- mutate(df, reject_rank1 = reject_temp1*rank)
    #Record the rank of the largest p-value that meets above condition
    total_rejected <- max(df$reject_rank1)
    #Second Stage
    #Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
    qval_2st <- qval_adj*(totalpvalues/(totalpvalues-total_rejected))
    #Generate value q_2st*r/M
    df <- mutate(df, fdr_temp2 = qval_2st*rank/totalpvalues)
    #Generate binary variable checking condition p(r) <= q_2st*r/M
    df <- mutate(df, reject_temp2 = if_else(fdr_temp2>=pval,1,0))
    #Generate variable containing p-value ranks for all p-values that meet above condition
    df <- mutate(df, reject_rank2 = reject_temp2*rank)
    #Record the rank of the largest p-value that meets above condition
    total_rejected2 <- max(df$reject_rank2)
    #A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
    df <- mutate(df, qval = if_else(rank <= total_rejected2, qv, qval))
    df <- select(df, Outcome, coef, pval, rank, qval)
    # Reduce q by 0.001 and repeat loop
    qv <- qv - .001
  }
  return(df)
}

##########################################################################################
#Figure 1: Take-up
##########################################################################################
#Overall
tu.reg1 <- felm(ever.borrow ~ treated + bin1 + bin2 + bin3|0|0,
                data = cur.cust)
summary(tu.reg1, robust = TRUE)

#By cross-randomized treatment
cur.cust <- mutate(cur.cust, NTimeLimit = if_else(treated==1 & TimeLimit==0,1,0),
                   LoMax = if_else(treated==1 & HiMax==0,1,0),
                   LoFee = if_else(treated==1 & HiFee==0,1,0))

tu.xrand <- felm(ever.borrow ~ treated:NTimeLimit:LoFee:LoMax + 
                   treated:NTimeLimit:LoFee:HiMax + treated:NTimeLimit:HiFee:LoMax +
                   treated:NTimeLimit:HiFee:HiMax + treated:TimeLimit:LoFee:LoMax + 
                   treated:TimeLimit:LoFee:HiMax + treated:TimeLimit:HiFee:LoMax +
                   treated:TimeLimit:HiFee:HiMax + bin1 + bin2 + bin3|0|0,
                 data = cur.cust)
summary(tu.xrand, robust = TRUE)

#By strata 
tu.het.reg1 <- felm(ever.borrow ~ treated:bin1 + treated:bin2 + 
                      treated:bin3 + treated:bin4|0|0,
                    data = cur.cust)
summary(tu.het.reg1, robust = TRUE)

#Get q-values 
coef <- c(tu.reg1$coefficients[2], tu.xrand$coefficients[5:12], 
          tu.het.reg1$coefficients[2:5])
pval <- c(tu.reg1$pval[2], tu.xrand$pval[5:12], 
          tu.het.reg1$pval[2:5])
SE <- c(tu.reg1$rse[2], tu.xrand$rse[5:12], tu.het.reg1$rse[2:5]) 
deg.f <- c(tu.reg1$df, rep(tu.xrand$df,8), rep(tu.het.reg1$df,4))
Outcome <- c("Pooled",
             "No Time Limit, 2% Fee, 7-day Limit",
             "No Time Limit, 2% Fee, 14-day Limit",
             "No Time Limit, 10% Fee, 7-day Limit",
             "No Time Limit, 10% Fee, 14-day Limit",
             "Time Limit, 2% Fee, 7-day Limit",
             "Time Limit, 2% Fee, 14-day Limit",
             "Time Limit, 10% Fee, 7-day Limit",
             "Time Limit, 10% Fee, 14-day Limit",
             "0%-30%","30%-65%","65%-80%","80%-100%")
Group <- c("Xrand",rep("Xrand",8),rep("Het",4))
tu.df <- as.data.frame(cbind(Outcome, Group, coef, pval, SE, deg.f))
tu.df$coef <- as.numeric(tu.df$coef)
tu.df$pval <- as.numeric(tu.df$pval)
tu.df$SE <- as.numeric(tu.df$SE)
tu.df$deg.f <- as.numeric(tu.df$deg.f)

#Generate q-values 
tu.df.q <- gen.qvals(tu.df)

tu.df <- left_join(tu.df, tu.df.q)

tu.df <- mutate(tu.df, CI.High = coef + qt(0.975,deg.f)*SE,
                CI.Low = coef - qt(0.975,deg.f)*SE,
                qcv = qt(0.975,deg.f), qz = abs(qnorm(qval/2)), 
                qSE = abs(coef/qz),
                qCIL = coef - (qcv*qSE), qCIH = coef + (qcv*qSE))
tu.df$Outcome <- factor(tu.df$Outcome, 
                        levels = c("0%-30%","30%-65%","65%-80%","80%-100%",
                                   "No Time Limit, 2% Fee, 7-day Limit",
                                   "No Time Limit, 2% Fee, 14-day Limit",
                                   "No Time Limit, 10% Fee, 7-day Limit",
                                   "No Time Limit, 10% Fee, 14-day Limit",
                                   "Time Limit, 2% Fee, 7-day Limit",
                                   "Time Limit, 2% Fee, 14-day Limit",
                                   "Time Limit, 10% Fee, 7-day Limit",
                                   "Time Limit, 10% Fee, 14-day Limit","Pooled"))
tu.df$Group <- factor(tu.df$Group, levels = c("Xrand","Het"))

TU.plot <- ggplot(data = tu.df, 
                  aes(x = coef, y = Outcome, fill = Group, color = Group)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  coord_cartesian(xlim = c(0,0.5)) + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = qCIL, xmax=qCIH), width = .05, position = position_dodge(0.6), alpha=0.5) + 
  labs(x = "Proportion Using the Line of Credit", y = "") + theme_bw() + 
  scale_fill_grey(start = 0, end = 0.6, aesthetics = c("fill","color")) + 
  theme(legend.position = "none") 

ggsave(filename="../Output/TU.png", plot=TU.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

##########################################################################################
#Figure 2: Price Elasticity of Demand for the Line of Credit
##########################################################################################
est.elas <- function(df, bin, ts){
  log <- felm(log.borrow ~ log.fee + log.fee:TimeLimit + daily.rate + TimeLimit + 
                util_90d + HiMax + bin1 + bin2 + bin3|0|0, data = df)
  log.out <- as.data.frame(cbind(log$coefficients[2], log$rse[2], log$df))
  colnames(log.out) <- c("coef","SE","DOF")
  log.out <- mutate(log.out, bin = bin, group = ts, spec = "log")
  out <- log.out
}
cur.cust$sd.wh[which(cur.cust$util_90d==0)] <- 0
cur.cust$sd.wh[which(is.na(cur.cust$sd.wh))] <- median(cur.cust$sd.wh, na.rm=T)
cur.cust <- mutate(cur.cust, highSD = if_else(sd.wh>median(sd.wh),1,0))

e0 <- est.elas(cur.cust[which(cur.cust$treated==1),], "Pooled","Pooled")
e1 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$bin1==1),], "0%-30%","Pooled")
e2 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$bin2==1),], "30%-65%", "Pooled")
e3 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$bin3==1),], "65%-80%", "Pooled")
e4 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$bin4==1),], "80%-100%", "Pooled")
e5 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$highSD==1),], "High SD", "Pooled")
e6 <- est.elas(cur.cust[which(cur.cust$treated==1 & cur.cust$highSD==0),], "Low SD", "Pooled")

elas.plot.data <- rbind(e0, e1, e2, e3, e4, e5, e6)
elas.plot.data <- mutate(elas.plot.data, cv = qt(0.025, DOF, lower.tail= FALSE),
                         CI.High = coef + cv*SE, CI.Low = coef - cv*SE)
elas.plot.data$bin <- factor(elas.plot.data$bin, levels = c("Low SD","High SD","80%-100%", "65%-80%", "30%-65%","0%-30%","Pooled"))

elas.plot.het <- ggplot(data = elas.plot.data[which(elas.plot.data$bin!="Low SD" & 
                                                      elas.plot.data$bin!="High SD"),],
                        aes(y = bin, x = coef)) + 
  geom_point(stat = "identity", position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_vline(xintercept = 0, linewidth = 0.1) + 
  labs(x = "Pre-Experimental Utilization Rate", y = "Price Elasticity of Demand") + theme_bw() 

ggsave(filename="../Output/Elas_Plot.png", plot=elas.plot.het, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

##########################################################################################
#Figure 3: ATE on Solar Demand
##########################################################################################
#Pooled
ur.reg <- felm(ur ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                 bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                 bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                 bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(ur.reg, robust = TRUE)

#By cross-randomized treatment
ur.reg.disag <- felm(ur ~ treated:as.factor(treatment) + bin1.1 + bin1.2 + bin1.3 + 
                       bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                       bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                       bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(ur.reg.disag, robust = TRUE)

ur.reg.het <- felm(ur ~ treated:bin1 + treated:bin2 + treated:bin3 + treated:bin4 + 
                     bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, 
                   data = ur)
summary(ur.reg.het, robust = TRUE)

ur <- mutate(ur, highSD = if_else(sd.wh>median(cur.cust$sd.wh,na.rm=T),1,0))

ur.reg.lsd <- felm(ur ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, 
                   data = ur[which(ur$highSD==0),])
summary(ur.reg.lsd, robust = TRUE)

ur.reg.hsd <- felm(ur ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, 
                   data = ur[which(ur$highSD==1),])
summary(ur.reg.hsd, robust = TRUE)

ur.plot.data <- as.data.frame(cbind(c(ur.reg$coefficients[1],ur.reg.lsd$coefficients[1], ur.reg.hsd$coefficients[1],
                                      ur.reg.het$coefficients[25:28], ur.reg.disag$coefficients[26:33]), 
                                    c(ur.reg$cse[1], ur.reg.lsd$cse[1], ur.reg.hsd$cse[1], ur.reg.het$cse[25:28],
                                      ur.reg.disag$cse[26:33]),
                                    c(ur.reg$cpval[1],ur.reg.lsd$cpval[1], ur.reg.hsd$cpval[1], 
                                      ur.reg.het$cpval[25:28], ur.reg.disag$cpval[26:33]),
                                    c("Pooled", "Low SD", "High SD","0%-30%","30%-65%","65%-80%","80%-100%",
                                      "No Time Limit, 2% Fee, 7-day Limit",
                                      "No Time Limit, 2% Fee, 14-day Limit",
                                      "No Time Limit, 10% Fee, 7-day Limit",
                                      "No Time Limit, 10% Fee, 14-day Limit",
                                      "Time Limit, 2% Fee, 7-day Limit",
                                      "Time Limit, 2% Fee, 14-day Limit",
                                      "Time Limit, 10% Fee, 7-day Limit",
                                      "Time Limit, 10% Fee, 14-day Limit"),
                                    c(ur.reg$df, ur.reg.lsd$df, ur.reg.hsd$df, rep(ur.reg.het$df,4),
                                      rep(ur.reg.disag$df,8))))
colnames(ur.plot.data) <- c("coef","SE","pval","Outcome","df")
ur.plot.data$df <- as.numeric(ur.plot.data$df)
ur.plot.data$pval <- as.numeric(ur.plot.data$pval)
ur.plot.data$coef <- as.numeric(ur.plot.data$coef)
ur.plot.data$SE <- as.numeric(ur.plot.data$SE)

#Generate q-values 
ur.q <- dplyr::select(ur.plot.data, Outcome, coef, pval)
ur.q <- gen.qvals(ur.q) ##Turns out that none of these effects can be rejected at any level of significance one we control FDR

ur.plot.data <- mutate(ur.plot.data, CI.High = coef + qt(0.975,df)*SE, CI.Low = coef - qt(0.975,df)*SE)

ur.plot.data$Outcome <- factor(ur.plot.data$Outcome, 
                               levels = c("0%-30%","30%-65%","65%-80%","80%-100%",
                                          "No Time Limit, 2% Fee, 7-day Limit",
                                          "No Time Limit, 2% Fee, 14-day Limit",
                                          "No Time Limit, 10% Fee, 7-day Limit",
                                          "No Time Limit, 10% Fee, 14-day Limit",
                                          "Time Limit, 2% Fee, 7-day Limit",
                                          "Time Limit, 2% Fee, 14-day Limit",
                                          "Time Limit, 10% Fee, 7-day Limit",
                                          "Time Limit, 10% Fee, 14-day Limit","Pooled",
                                          "Low SD","High SD"))

ur.means <- cmeans(outcome="ur")
ur.plot.data <- left_join(ur.plot.data, ur.means, by = c("Outcome"="bin"))

UR.plot <- ggplot(data = ur.plot.data[which(ur.plot.data$Outcome!="Low SD" & 
                                              ur.plot.data$Outcome!="High SD"),], 
                  aes(x = coef, y = Outcome)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_point(aes(y = Outcome, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  labs(x = "ATE on Demand for Solar", y = "") + theme_bw() + 
  theme(legend.position = "none") 

ggsave(filename="../Output/UR.png", plot=UR.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

##########################################################################################
#Figure 4: ATE on Default/Repo
##########################################################################################
#Pooled 
repo.reg <- felm(repo ~ treated + bin1 + bin2 + bin3 + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                 data = cur.cust)
summary(repo.reg, robust = TRUE)

#High versus low limit
repo.reg1 <- felm(repo ~ HiMax + LoMax + bin1 + bin2 + bin3 + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                  data = cur.cust)
summary(repo.reg1, robust = TRUE)

#By strata pooled
repo.het.reg <- felm(repo ~ treated:bin1 + treated:bin2 + 
                       treated:bin3 + treated:bin4 + util_90d + bin1 + bin2 + bin3 + TimeLimit + LoFee + daily.rate|0|0,
                     data = cur.cust)
summary(repo.het.reg, robust = TRUE)

#By strata high versus low limit
repo.reg2 <- felm(repo ~ HiMax + LoMax + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                  data = cur.cust[which(cur.cust$bin1==1),])
summary(repo.reg2, robust = TRUE)

repo.reg3 <- felm(repo ~ HiMax + LoMax + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                  data = cur.cust[which(cur.cust$bin2==1),])
summary(repo.reg3, robust = TRUE)

repo.reg4 <- felm(repo ~ HiMax + LoMax + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                  data = cur.cust[which(cur.cust$bin3==1),])
summary(repo.reg4, robust = TRUE)

repo.reg5 <- felm(repo ~ HiMax + LoMax + util_90d + TimeLimit + LoFee + daily.rate|0|0,
                  data = cur.cust[which(cur.cust$bin4==1),])
summary(repo.reg5, robust = TRUE)

#Get q-values 
coef <- c(repo.reg$coefficients[2], repo.het.reg$coefficients[9:12],repo.reg1$coefficients[2:3],
          repo.reg2$coefficients[2:3], repo.reg3$coefficients[2:3], repo.reg4$coefficients[2:3], repo.reg5$coefficients[2:3])
pval <- c(repo.reg$pval[2], repo.het.reg$pval[9:12],repo.reg1$pval[2:3],
          repo.reg2$pval[2:3], repo.reg3$pval[2:3], repo.reg4$pval[2:3], repo.reg5$pval[2:3])
SE <- c(repo.reg$rse[2], repo.het.reg$rse[9:12],repo.reg1$rse[2:3],
        repo.reg2$rse[2:3], repo.reg3$rse[2:3], repo.reg4$rse[2:3], repo.reg5$rse[2:3])
deg.f <- c(repo.reg$df, rep(repo.het.reg$df,4), rep(repo.reg1$df,2), rep(repo.reg2$df,2), rep(repo.reg3$df,2),
           rep(repo.reg4$df,2), rep(repo.reg5$df,2))
Outcome <- c("Pooled",
             "0%-30%","30%-65%","65%-80%","80%-100%",
             "14-day Limit","7-day Limit",
             "0%-30%, 14-day Limit","0%-30%, 7-day Limit",
             "30%-65%, 14-day Limit","30%-65%, 7-day Limit",
             "65%-80%, 14-day Limit","65%-80%, 7-day Limit",
             "80%-100%, 14-day Limit", "80%-100%, 7-day Limit")
Group <- c(rep("NR",5), rep("R",10))
repo.df <- as.data.frame(cbind(Outcome, Group, coef, pval, SE, deg.f))
repo.df$coef <- as.numeric(repo.df$coef)
repo.df$pval <- as.numeric(repo.df$pval)
repo.df$SE <- as.numeric(repo.df$SE)
repo.df$deg.f <- as.numeric(repo.df$deg.f)

#Generate q-values 
repo.df.q <- gen.qvals(repo.df) #None are different than 1

repo.df <- mutate(repo.df, CI.High = coef + qt(0.975,deg.f)*SE,
                  CI.Low = coef - qt(0.975,deg.f)*SE)
repo.df$Outcome <- factor(repo.df$Outcome, 
                          levels = c("0%-30%, 14-day Limit","0%-30%, 7-day Limit","0%-30%",
                                     "30%-65%, 14-day Limit","30%-65%, 7-day Limit","30%-65%",
                                     "65%-80%, 14-day Limit","65%-80%, 7-day Limit","65%-80%",
                                     "80%-100%, 14-day Limit","80%-100%, 7-day Limit","80%-100%",
                                     "14-day Limit","7-day Limit","Pooled"))
repo.df$Group <- factor(repo.df$Group, levels = c("R","NR"))

#Get control means 
repo.means <- cmeans(outcome="repo")
repo.df <- left_join(repo.df, repo.means, by = c("Outcome"="bin"))

repo.plot <- ggplot(data = repo.df, 
                    aes(x = coef, y = Outcome, fill = Group, color = Group)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_point(aes(y = Outcome, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  labs(x = "ATE on Default", y = "") + theme_bw() + 
  scale_fill_grey(start = 0, end = 0.6, aesthetics = c("fill","color")) + 
  theme(legend.position = "none")

ggsave(filename="../Output/Repo.png", plot=repo.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

##########################################################################################
#Figure 5: ATEs on mechanisms: # transactions, transaction sizes, and wH used 
##########################################################################################
#Number of transactions
nt.reg <- felm(ntrans ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                 bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                 bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                 bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(nt.reg, robust = TRUE)

nt.reg.het <- felm(ntrans ~ treated:bin1 + treated:bin2 + treated:bin3 + treated:bin4 + 
                     bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, 
                   data = ur)
summary(nt.reg.het, robust = TRUE)

nt.plot.data <- as.data.frame(cbind(c(nt.reg$coefficients[1],nt.reg.het$coefficients[25:28]), 
                                    c(nt.reg$cse[1],nt.reg.het$cse[25:28]),
                                    c(nt.reg$pval[1],nt.reg.het$pval[25:28]),
                                    c("NT Pooled","NT 0%-30%","NT 30%-65%","NT 65%-80%","NT 80%-100%"),
                                    c(nt.reg$df, rep(nt.reg.het$df,4))))
colnames(nt.plot.data) <- c("coef","SE","pval","Outcome","df")
nt.plot.data$df <- as.numeric(nt.plot.data$df)
nt.plot.data$pval <- as.numeric(nt.plot.data$pval)
nt.plot.data$coef <- as.numeric(nt.plot.data$coef)
nt.plot.data$SE <- as.numeric(nt.plot.data$SE)

#Transaction Size
ts.reg <- felm(mean.trans.size ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                 bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                 bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                 bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(ts.reg, robust = TRUE)

ts.reg.het <- felm(mean.trans.size ~ treated:bin1 + treated:bin2 + treated:bin3 + treated:bin4 + 
                     bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, 
                   data = ur)
summary(ts.reg.het, robust = TRUE)

ts.plot.data <- as.data.frame(cbind(c(ts.reg$coefficients[1],ts.reg.het$coefficients[25:28]), 
                                    c(ts.reg$cse[1],ts.reg.het$cse[25:28]),
                                    c(ts.reg$pval[1],ts.reg.het$pval[25:28]),
                                    c("TS Pooled","TS 0%-30%","TS 30%-65%","TS 65%-80%","TS 80%-100%"),
                                    c(ts.reg$df, rep(ts.reg.het$df,4))))
colnames(ts.plot.data) <- c("coef","SE","pval","Outcome","df")
ts.plot.data$df <- as.numeric(ts.plot.data$df)
ts.plot.data$pval <- as.numeric(ts.plot.data$pval)
ts.plot.data$coef <- as.numeric(ts.plot.data$coef)
ts.plot.data$SE <- as.numeric(ts.plot.data$SE)

#wH Used
wh.reg <- felm(wh.out ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                 bin1.4 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + 
                 bin3.1 + bin3.2 + bin3.3 + bin3.4 + 
                 bin4.1 + bin4.2 + bin4.3 + bin4.4 |id|0|id, data = ur)
summary(wh.reg, robust = TRUE)

wh.reg.het <- felm(wh.out ~ treated:bin1 + treated:bin2 + treated:bin3 + treated:bin4 + 
                     bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4|id|0|id, 
                   data = ur)
summary(wh.reg.het, robust = TRUE)

wh.plot.data <- as.data.frame(cbind(c(wh.reg$coefficients[1],wh.reg.het$coefficients[17:20]), 
                                    c(wh.reg$cse[1],wh.reg.het$cse[17:20]),
                                    c(wh.reg$pval[1],wh.reg.het$pval[17:20]),
                                    c("WH Pooled","WH 0%-30%","WH 30%-65%","WH 65%-80%","WH 80%-100%"),
                                    c(wh.reg$df, rep(wh.reg.het$df,4))))
colnames(wh.plot.data) <- c("coef","SE","pval","Outcome","df")
wh.plot.data$df <- as.numeric(wh.plot.data$df)
wh.plot.data$pval <- as.numeric(wh.plot.data$pval)
wh.plot.data$coef <- as.numeric(wh.plot.data$coef)
wh.plot.data$SE <- as.numeric(wh.plot.data$SE)

mech.df <- rbind(nt.plot.data, ts.plot.data, wh.plot.data)

#Generate q-values 
mech.q <- gen.qvals(mech.df) ##Turns out that none of these effects can be rejected at any level of significance one we control FDR

mech.df <- left_join(mech.df, mech.q)

mech.df <- mutate(mech.df, Out = substr(Outcome,1,2), bin = substr(Outcome, 4,11))
mech.df$bin <- factor(mech.df$bin, levels = c("80%-100%","65%-80%","30%-65%","0%-30%","Pooled"))

mech.df <- mutate(mech.df, CI.High = coef + qt(0.975,df)*SE, CI.Low = coef - qt(0.975,df)*SE,
                  qcv = qt(0.975,deg.f), qz = abs(qnorm(qval/2)), 
                  qSE = abs(coef/qz),
                  qCIL = coef - (qcv*qSE), qCIH = coef + (qcv*qSE))

nt.means <- cmeans(outcome="nt")
ts.means <- cmeans(outcome = "ts")
wh.means <- cmeans(outcome = "wh")

nt.df <- filter(mech.df, Out=="NT")
ts.df <- filter(mech.df, Out=="TS")
wh.df <- filter(mech.df, Out=="WH")

nt.df <- left_join(nt.df, nt.means)
ts.df <- left_join(ts.df, ts.means)
wh.df <- left_join(wh.df, wh.means)

NT.plot <- ggplot(data = nt.df, aes(x = coef, y = bin)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_point(aes(y = bin, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = qCIL, xmax=qCIH), width = .05, position = position_dodge(0.6), alpha=0.5) + 
  labs(x = "ATE on In-Person Transactions", y = "") + theme_bw() + 
  theme(legend.position = "none")  

ggsave(filename="../Output/NT.png", plot=NT.plot, device="png",
       height=2, width=5.41, units="in", dpi=300, pointsize = 7)

TS.plot <- ggplot(data = ts.df, aes(x = coef, y = bin)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_point(aes(y = bin, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = qCIL, xmax=qCIH), width = .05, position = position_dodge(0.6), alpha=0.5) + 
  labs(x = "ATE on Transaction Size (Days)", y = "") + theme_bw() + 
  theme(legend.position = "none")

ggsave(filename="../Output/TS.png", plot=TS.plot, device="png",
       height=2, width=5.41, units="in", dpi=300, pointsize = 7)

WH.plot <- ggplot(data = wh.df, aes(x = coef, y = bin)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_point(aes(y = bin, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = qCIL, xmax=qCIH), width = .05, position = position_dodge(0.6), alpha=0.5) + 
  labs(x = "ATE on Watt Hours Consumed", y = "") + theme_bw() + 
  theme(legend.position = "none") 

ggsave(filename="../Output/WH.png", plot=WH.plot, device="png",
       height=2, width=5.41, units="in", dpi=300, pointsize = 7)
##########################################################################################
#Appendix Figures
##########################################################################################
#####Figure A1: Appliance Ownership#####
load("Clean_Use_RW.Rda")
apps <- select(use.rw, customer_id, Radio, Torch, TV, Shaver, Phone, Charger, Only_Lights)
rm(use.rw)
apps <- filter(apps, !is.na(Radio) & !is.na(Torch) & !is.na(TV))
apps <- unique(apps)

apps <- filter(apps, !is.na(Only_Lights)) %>%
  mutate(RadTor = if_else(Radio>=1 & Torch>=1,1,0), RadTV = if_else(Radio>=1 & TV>=1,1,0),
         TorTV = if_else(Torch>=1 & TV>=1,1,0), RadTorTV = if_else(Radio>=1 & Torch>=1 & TV>=1,1,0))
apps <- left_join(ids, apps, by = c("customerid" = "customer_id"))
apps <- left_join(apps, dr.all, by = c("uniquecustomerid" = "unique_customer_id"))

apps.fig.data <- select(apps, Radio, Torch, TV, Shaver, Phone, Charger, Only_Lights) %>% group_by() %>%
  summarise(radio = sum(Radio, na.rm=T), torch = sum(Torch, na.rm=T), shaver = sum(Shaver, na.rm=T), tv = sum(TV, na.rm=T), phone = sum(Phone, na.rm=T),
            charger = sum(Charger, na.rm=T), onlylights = sum(Only_Lights, na.rm=T)) %>% select(-charger, -phone)
apps.fig.data <- as.matrix(apps.fig.data) %>% t() %>% as.data.frame()
apps.fig.data$appliance <- rownames(apps.fig.data)
apps.fig.data <- mutate(apps.fig.data, pct = V1/(sum(apps.fig.data$V1)))

apps.fig <- ggplot(data = apps.fig.data, aes(x = reorder(appliance, -V1), y = pct)) + 
  geom_bar(stat = "identity") + labs(x = "Appliance", y = "Proportion Customers") + 
  theme_bw() 

ggsave(filename="../Output/Appliances.png", plot=apps.fig, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A4: pre-experimental purchasing behavior#####
bp.data <- filter(pmt.panel, exp.month <= 3)
strata <- select(cur.cust, customer.id, util_band)
bp.data <- left_join(bp.data, strata, by = c("unique_customer_id" = "customer.id"))
bp.data <- mutate(bp.data, strata = if_else(util_band==0, "0%-30%", if_else(util_band==1,"30%-65%",
                                                                            if_else(util_band==2,"65%-80%","80%-100%"))))
ntrans.plot <- ggplot(bp.data[which(bp.data$ntrans<=10),], aes(x=strata, y=ntrans, group = strata)) + geom_boxplot(notch=FALSE) + 
  labs(x = "Pre-experimental Demand",
       y = "Number of Transactions in a Month") + theme_bw() 

ggsave(filename="../Output/Ntrans_Pre.png", plot=ntrans.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

transsize.plot <- ggplot(bp.data[which(bp.data$mean.trans.size<=30),], aes(x=strata, y=mean.trans.size, group = strata)) + 
  geom_boxplot(notch=FALSE) + 
  labs(x = "Pre-experimental Demand",
       y = "Mean Transaction Size") + theme_bw()

ggsave(filename="../Output/Meantrans_Pre.png", plot=transsize.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A6: Knowledge of mobile money#####
know.mm <- select(phone.sur, hhid, mm.know, util_band) %>% 
  mutate(counter=1) %>%
  group_by(mm.know, util_band) %>% summarise(total = sum(counter)) 

util.totals <- select(phone.sur, hhid, mm.know, util_band) %>%
  mutate(counter=1) %>% group_by(util_band) %>% summarise(util.tot = sum(counter))

know.mm <- left_join(know.mm, util.totals, by = "util_band")
know.mm <- mutate(know.mm, pct = total/util.tot, 
                  bin = if_else(util_band==0,"0%-30%",
                                if_else(util_band==1,"30%-65%",
                                        if_else(util_band==2,"65%-80%","80%-100%"))))

mm.know.plot <- ggplot(data = know.mm[which(know.mm$mm.know==1),], aes(x = bin, y = pct)) + 
  geom_bar(stat = "identity", color = "steelblue1",fill = "steelblue1") + 
  labs(x = "Pre-Experimental Demand",
       y = "Proportion of Survey Respondents",
       title = "Most Consumers know How to Use Mobile Money") + theme_bw()

ggsave(filename="../Output/MMKnow.png", plot=mm.know.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A7: consumer tenure and daily rate#####
tenure <- mutate(ur.raw, start.date = as.Date(paygostartdate)) %>% mutate(tenure = as.Date("2019-10-14") - start.date) %>%
  select(uniquecustomerid, tenure) %>% unique()
cur.cust <- left_join(cur.cust, tenure, by = c("customer.id" = "uniquecustomerid"))
cur.cust$tenure <- as.numeric(cur.cust$tenure)

tenure.dr.data <- filter(cur.cust, daily.rate<=500) %>% group_by(daily.rate) %>%
  summarize(mean.tenure = mean(tenure, na.rm=T))

tenure.dr.plot <- ggplot(data = tenure.dr.data, aes(x = daily.rate, y = mean.tenure)) + geom_point() + 
  geom_smooth(method = "lm") + labs(x = "Daily Rate (RWF)", y = "Average Tenure (days)") + theme_bw() 

ggsave(filename="../Output/TenureDR.png", plot=tenure.dr.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A8: comparison of wealth distributions#####
eicv <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S0_S5_Household.dta")
eicv <- select(eicv, hhid, province, district, ur, region, weight, pop_wt, ubudehe = s0qb,
               light.source = s5cq16, elec.source = s5cq16a1, solar = s5cq16a21, 
               elec.exp.4wk = s5cq17, wall = s5dq1, roof = s5dq2, floor = s5dq3)

eicv.2 <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S8A3_expenditure.dta")
eicv.2 <- select(eicv.2, hhid, article = s8a3q0, exp.7days = s8a3q3)

eicv.food <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S8B_expenditure.dta")
eicv.food <- select(eicv.food, hhid, article = s8bq0, exp.7days = s8bq3)

#Transform the expenditures data into a wide dataframe before joining with other covariates
candle <- filter(eicv.2, article=="Candle") %>% select(hhid, candle.exp = exp.7days)
bat <- filter(eicv.2, article=="Batteries") %>% select(hhid, battery.exp = exp.7days)
phone <- filter(eicv.2, article=="Mobile phone battery recharging") %>% 
  select(hhid, phone.exp = exp.7days)
kerosene <- filter(eicv.2, article=="Kerosene") %>% select(hhid, kerosene.exp = exp.7days)
wood <- filter(eicv.2, article=="Wood _cooking_") %>% select(hhid, wood.exp = exp.7days)

exp <- full_join(candle, bat, by = "hhid")
exp <- full_join(exp, phone, by = "hhid")
exp <- full_join(exp, kerosene, by = "hhid")
exp <- full_join(exp, wood, by = "hhid")

# Add in total expenditures to give a sense of the price of solar 
total <- select(eicv.2, everything()) %>% group_by(hhid) %>% summarise(total.hhexp = sum(exp.7days, na.rm=T))
total.food <- select(eicv.food, everything()) %>% group_by(hhid) %>% 
  summarise(total.hhexp = sum(exp.7days, na.rm=T))
total <- rbind(total, total.food)
total <- select(total, everything()) %>% group_by(hhid) %>% summarise(total.exp = sum(total.hhexp, na.rm=T))
exp <- left_join(exp, total, by = "hhid")

eicv <- left_join(eicv,exp)

#Read in data about household composition
eicv.3 <- read.dta("rwa-nisr-EICV5-data_STATA/cs_S1_S2_S3_S4_S6A_S6E_Person.dta")
eicv.3 <- select(eicv.3, hhid, sex = s1q1, age = s1q3y, absent = s1q7, length.absent = s1q8,
                 hh.member = s1q16) 
eicv.3$out <- as.numeric(gsub("([0-9]+).*$", "\\1", eicv.3$length.absent))
eicv.3 <- mutate(eicv.3, absent.ind = if_else(absent=="Yes",1,0),
                 length.num = if_else(is.na(out),0,out),
                 hh.ind = if_else(hh.member=="Yes",1,0),
                 adult = if_else(age>=18,1,0),
                 child = if_else(age<18,1,0),
                 present.proportion = 1-(length.num/12),
                 weighted.member = hh.ind*present.proportion,
                 male = if_else(sex=="Male",1,0),
                 female = if_else(sex=="Female",1,0))

hh.size <- select(eicv.3, everything()) %>% group_by(hhid) %>%
  summarise(hhsize = sum(hh.ind,na.rm=T),
            hhsize.wt = sum(weighted.member,na.rm=T),
            adults = sum(adult,na.rm=T),
            children = sum(child,na.rm=T),
            male.total = sum(male,na.rm=T),
            female.total = sum(female,na.rm=T))

eicv <- left_join(eicv, hh.size, by = "hhid")

#Rank wall, roof, and floor materials in a similar manner to what I did in the phone survey
eicv <- mutate(eicv, wall.num = if_else(wall=="Tree trunks with mud and cement"|
                                          wall=="Tree trunks with mud"|
                                          wall=="Wooden planks",1,
                                        if_else(wall=="Mud bricks",2,
                                                if_else(wall=="Mud bricks covered with cement",3,
                                                        if_else(wall=="OVen fired bricks"|
                                                                  wall=="Cement bricks"|
                                                                  wall=="Stones",4,as.double(NA))))),
               roof.num = if_else(roof=="Local clay tiles"|roof=="Industrial tiles",2,
                                  if_else(roof=="Metal sheets/ corrugated iron"|
                                            roof=="Concrete"|roof=="Plastic/plywood/impermanent materials"|
                                            roof=="Thatch / leaves/grass",1,as.double(NA))),
               floor.num = if_else(floor=="Hardened dung Bricks"|floor=="Beaten earth",2,
                                   if_else(floor=="Cement"|floor=="Clay tiles"|floor=="Wooden floor",3,
                                           as.double(NA))),
               ub.cat = if_else(ubudehe=="Category 1",1,
                                if_else(ubudehe=="Category 2",2,
                                        if_else(ubudehe=="Category 3",3,
                                                if_else(ubudehe=="Category 4",4,as.double(NA))))),
               grid.access = if_else(elec.source=="National Grid Connection"|
                                       elec.source=="Local Mini Grid",1,0),
               elec.cat = if_else(elec.source=="No electricity",1,
                                  if_else(elec.source=="Solar Lantern"|elec.source=="Rechargeable Batteries",2,
                                          if_else(elec.source=="Solar Home System",3,
                                                  if_else(elec.source=="National Grid Connection"|
                                                            elec.source=="Local Mini Grid",4,as.double(NA))))),
               energy.exp = candle.exp + battery.exp + phone.exp + kerosene.exp + wood.exp,
               light.cat = if_else(light.source=="Firewood"|light.source=="Candle",1,
                                   if_else(light.source=="Oil Lamp"|light.source=="Torch/Phone"|
                                             light.source=="Lantern _Agatadowa_",2,
                                           if_else(light.source=="Batteries+ Bulb"|
                                                     light.source=="Rechargeable battery",3,
                                                   if_else(light.source=="Solar panel",4,
                                                           if_else(light.source=="Electricity from EUCL"|
                                                                     light.source=="Other electricity distributors",5,as.double(NA)))))))

#Instead, make dummy variables for each category I want to use in PCA
eicv <- mutate(eicv, wcat.1 = if_else(wall.num==1,1,0),
               wcat.2 = if_else(wall.num==2,1,0),
               wcat.3 = if_else(wall.num==3,1,0),
               wcat.4 = if_else(wall.num==4,1,0),
               rcat.1 = if_else(roof.num==1,1,0),
               rcat.2 = if_else(roof.num==2,1,0),
               fcat.1 = if_else(floor.num==2,1,0),
               fcat.2 = if_else(floor.num==3,1,0),
               ecat.1 = if_else(elec.cat==1,1,0),
               ecat.2 = if_else(elec.cat==2,1,0),
               ecat.3 = if_else(elec.cat==3,1,0),
               ecat.4 = if_else(elec.cat==4,1,0),
               lcat.1 = if_else(light.cat==1,1,0),
               lcat.2 = if_else(light.cat==2,1,0),
               lcat.3 = if_else(light.cat==3,1,0),
               lcat.4 = if_else(light.cat==4,1,0),
               lcat.5 = if_else(light.cat==5,1,0),
               ucat.1 = if_else(ub.cat==1,1,0),
               ucat.2 = if_else(ub.cat==2,1,0),
               ucat.3 = if_else(ub.cat==3,1,0),
               ucat.4 = if_else(ub.cat==4,1,0),
               hhid = as.character(hhid))

phone.sur <- mutate(phone.sur, bin1 = if_else(ur.90d<0.3,1,0),
                    bin2 = if_else(ur.90d>=0.3 & ur.90d<0.65,1,0),
                    bin3 = if_else(ur.90d>=0.65 & ur.90d<0.8,1,0),
                    bin4 = if_else(ur.90d>=0.8,1,0))
phone.stack <- select(phone.sur, uniquecustomerid, wall, floor, roof, ub.cat, energy.exp, 
                      grid.access, bin1, bin2, bin3, bin4) %>%
  mutate(wcat.1 = if_else(wall==1,1,0),
         wcat.2 = if_else(wall==2,1,0),
         wcat.3 = if_else(wall==3,1,0),
         wcat.4 = if_else(wall==4,1,0),
         rcat.1 = if_else(roof==1,1,0),
         rcat.2 = if_else(roof==2,1,0),
         fcat.1 = if_else(floor==1|floor==2,1,0),
         fcat.2 = if_else(floor==3,1,0),
         ecat.1 = 0,
         ecat.2 = 0,
         ecat.3 = if_else(grid.access==0,1,0),
         ecat.4 = if_else(grid.access==1,1,0),
         lcat.1 = 0,
         lcat.2 = 0,
         lcat.3 = 0,
         lcat.4 = if_else(grid.access==0,1,0),
         lcat.5 = if_else(grid.access==1,1,0),
         ucat.1 = if_else(ub.cat==1,1,0),
         ucat.2 = if_else(ub.cat==2,1,0),
         ucat.3 = if_else(ub.cat==3,1,0),
         ucat.4 = if_else(ub.cat==4,1,0),
         ur = "Rural",
         weight = NA,
         pop_wt = NA) %>%
  select(hhid = uniquecustomerid, ur, weight, pop_wt, energy.exp, grid.access,
         wcat.1, wcat.2, wcat.3, wcat.4, rcat.1, rcat.2, fcat.1, fcat.2, ecat.1,
         ecat.2, ecat.3, ecat.4, lcat.1, lcat.2, lcat.3, lcat.4, lcat.5,
         ucat.1, ucat.2, ucat.3, ucat.4, bin1, bin2, bin3, bin4)

eicv.stack <- select(eicv, hhid, ur, weight, pop_wt, energy.exp, grid.access, wcat.1,
                     wcat.2, wcat.3, wcat.4, rcat.1, rcat.2, fcat.1, fcat.2, ecat.1,
                     ecat.2, ecat.3, ecat.4, lcat.1, lcat.2, lcat.3, lcat.4, lcat.5,
                     ucat.1, ucat.2, ucat.3, ucat.4) %>%
  mutate(bin1 = NA, bin2 = NA, bin3 = NA, bin4 = NA)

all <- rbind(eicv.stack, phone.stack)

#Remove urban households and do PCA on the resulting data
all <- filter(all, ur!="Urban") %>%
  filter(!is.na(energy.exp) & !is.na(grid.access) & !is.na(wcat.1) & !is.na(wcat.2) & 
           !is.na(wcat.3) & !is.na(wcat.4) & !is.na(rcat.1) & !is.na(rcat.2) & !is.na(fcat.1) &
           !is.na(fcat.2) & !is.na(ecat.1) & !is.na(ecat.2) & !is.na(ecat.3) & !is.na(ecat.4) & 
           !is.na(lcat.1) & !is.na(lcat.2) & !is.na(lcat.3) & !is.na(lcat.4) & !is.na(lcat.5) &
           !is.na(ucat.1) & !is.na(ucat.2) & !is.na(ucat.3) & !is.na(ucat.4))

index.all.mat <- as.matrix(all[,c(5:27)])

test.pca.all <- prcomp(index.all.mat, center = TRUE, scale = TRUE)
summary(test.pca.all)

scores <- as.data.frame(test.pca.all$x)

all <- cbind(all, scores)

#Weight the data (this is probably a dumb way to do this but whatever)
eicv.only <- select(all, weight, pop_wt, PC1) %>% filter(!is.na(weight))
hist.data <- as.data.frame(rep(eicv.only$PC1[1],round(eicv.only$weight[1],0)))
colnames(hist.data) <- "PC1"

for (i in 2:length(eicv.only$weight)) {
  v <- eicv.only$PC1[i]
  rep <- round(eicv.only$weight[i],0)
  add.data <- as.data.frame(rep(eicv.only$PC1[i], round(eicv.only$weight[i],0)))
  colnames(add.data) <- "PC1"
  hist.data <- rbind(hist.data, add.data)
}

bb.only <- select(all, PC1, bin1, bin2, bin3, bin4) %>% 
  filter(!is.na(bin1) & !is.na(bin2) & !is.na(bin3) & !is.na(bin4)) %>%
  mutate(bin = if_else(bin1==1,1,
                       if_else(bin2==1,2,
                               if_else(bin3==1,3,
                                       if_else(bin4==1,4,as.double(NA)))))) %>%
  group_by(bin) %>% summarise(mean.wi = mean(PC1))

bb.weights <- select(cur.cust, util_band) %>% mutate(counter = 1) %>%
  group_by(util_band) %>% summarise(total = sum(counter)) %>%
  mutate(pct = total/sum(total))

bb.only <- cbind(bb.only, bb.weights)
bb.only <- mutate(bb.only, weighted = pct*mean.wi)
bb.mean <- sum(bb.only$weighted)

wealth.dist <- ggplot(data = hist.data, aes(PC1)) + geom_histogram(binwidth = 0.1) + 
  geom_vline(xintercept = bb.mean, color = "blue") + 
  geom_vline(xintercept = mean(hist.data$PC1),  color = "red") + 
  labs(x = "Wealth Index", y = "Number of Rural Households") + 
  theme_bw() 

ggsave(filename="../Output/EICV_Comp.png", plot=wealth.dist, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A9: distribution of pre-experimental demand#####
ur.plot.data <- filter(ur, month<=3) %>% group_by(uniquecustomerid) %>%
  summarise(pre.UR = mean(ur,na.rm=T))

ur.dist <- ggplot(ur.plot.data, aes(pre.UR)) + geom_histogram(binwidth = 0.05, color = "steelblue1",
                                                              fill = "steelblue1") + 
  geom_vline(xintercept = 0.3) + geom_vline(xintercept = 0.65) + 
  geom_vline(xintercept = 0.8) + 
  labs(x = "90-Day Pre-Experimental Utilization Rate", y = "Number of Consumers") + theme_bw() + 
  theme(plot.title = element_text(hjust = 0.5)) 

ggsave(filename="../Output/Util_Dist.png", plot=ur.dist, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A10: Elasticity by pre-experimental variation in use#####
elas.plot.het.sd <- ggplot(data = elas.plot.data[which(elas.plot.data$bin=="Low SD" | 
                                                         elas.plot.data$bin=="High SD"),],
                           aes(y = bin, x = coef)) + 
  geom_point(stat = "identity", position = position_dodge(0.6)) + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  geom_vline(xintercept = 0, linewidth = 0.1) + 
  labs(x = "Pre-Experimental Variance in Use", y = "Price Elasticity of Demand") + theme_bw() 

ggsave(filename="../Output/Elas_Plot_SD.png", plot=elas.plot.het.sd, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A11: ATEs on UR by pre-experimental variation in use#####
ur.plot.data <- as.data.frame(cbind(c(ur.reg$coefficients[1],ur.reg.lsd$coefficients[1], ur.reg.hsd$coefficients[1],
                                      ur.reg.het$coefficients[25:28], ur.reg.disag$coefficients[26:33]), 
                                    c(ur.reg$cse[1], ur.reg.lsd$cse[1], ur.reg.hsd$cse[1], ur.reg.het$cse[25:28],
                                      ur.reg.disag$cse[26:33]),
                                    c(ur.reg$cpval[1],ur.reg.lsd$cpval[1], ur.reg.hsd$cpval[1], 
                                      ur.reg.het$cpval[25:28], ur.reg.disag$cpval[26:33]),
                                    c("Pooled", "Low SD", "High SD","0%-30%","30%-65%","65%-80%","80%-100%",
                                      "No Time Limit, 2% Fee, 7-day Limit",
                                      "No Time Limit, 2% Fee, 14-day Limit",
                                      "No Time Limit, 10% Fee, 7-day Limit",
                                      "No Time Limit, 10% Fee, 14-day Limit",
                                      "Time Limit, 2% Fee, 7-day Limit",
                                      "Time Limit, 2% Fee, 14-day Limit",
                                      "Time Limit, 10% Fee, 7-day Limit",
                                      "Time Limit, 10% Fee, 14-day Limit"),
                                    c(ur.reg$df, ur.reg.lsd$df, ur.reg.hsd$df, rep(ur.reg.het$df,4),
                                      rep(ur.reg.disag$df,8))))
colnames(ur.plot.data) <- c("coef","SE","pval","Outcome","df")
ur.plot.data$df <- as.numeric(ur.plot.data$df)
ur.plot.data$pval <- as.numeric(ur.plot.data$pval)
ur.plot.data$coef <- as.numeric(ur.plot.data$coef)
ur.plot.data$SE <- as.numeric(ur.plot.data$SE)

#Generate q-values 
ur.q <- dplyr::select(ur.plot.data, Outcome, coef, pval)
ur.q <- gen.qvals(ur.q) ##Turns out that none of these effects can be rejected at any level of significance one we control FDR

ur.plot.data <- mutate(ur.plot.data, CI.High = coef + qt(0.975,df)*SE, CI.Low = coef - qt(0.975,df)*SE)

ur.plot.data$Outcome <- factor(ur.plot.data$Outcome, 
                               levels = c("0%-30%","30%-65%","65%-80%","80%-100%",
                                          "No Time Limit, 2% Fee, 7-day Limit",
                                          "No Time Limit, 2% Fee, 14-day Limit",
                                          "No Time Limit, 10% Fee, 7-day Limit",
                                          "No Time Limit, 10% Fee, 14-day Limit",
                                          "Time Limit, 2% Fee, 7-day Limit",
                                          "Time Limit, 2% Fee, 14-day Limit",
                                          "Time Limit, 10% Fee, 7-day Limit",
                                          "Time Limit, 10% Fee, 14-day Limit","Pooled",
                                          "Low SD","High SD"))

ur.means <- cmeans(outcome="ur")
ur.plot.data <- left_join(ur.plot.data, ur.means, by = c("Outcome"="bin"))

UR.plot.sd <- ggplot(data = ur.plot.data[which(ur.plot.data$Outcome=="Low SD" | 
                                                 ur.plot.data$Outcome=="High SD"),], 
                     aes(x = coef, y = Outcome)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_point(aes(y = Outcome, x = Cmean), stat = "identity", shape = "triangle", position = position_dodge(0.6), size = 1) +
  geom_vline(xintercept = 0, color = "grey") + 
  geom_errorbar(aes(xmin = CI.Low, xmax=CI.High), width = .1, position = position_dodge(0.6)) + 
  labs(x = "ATE on Demand for Solar", y = "") + theme_bw() + 
  theme(legend.position = "none") 

ggsave(filename="../Output/UR_SD.png", plot=UR.plot.sd, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A12: Growth in take-up over time#####
first <- ldf.full %>% group_by(customer.id) %>% summarise(first.date = min(req.date, na.rm=T))
first$week <- as.numeric(strftime(first$first.date, format = "%V"))
first <- mutate(first, exp.week = if_else(week>=42, week-41,week + 11), counter = 1) %>%
  mutate(exp.month = if_else(exp.week<=4,1,if_else(exp.week>4 & exp.week<=8,2,
                                                   if_else(exp.week>8 & exp.week<=12,3,4)))) %>% 
  group_by(exp.week) %>% summarise(new.borrowers = sum(counter, na.rm=T)) %>%
  mutate(cum.new = if_else(exp.week==1,new.borrowers,as.double(NA)))
for (i in 2:length(first$exp.week)){
  first$cum.new[i] <- first$cum.new[i-1] + first$new.borrowers[i]
}
first <- rename(first, total = cum.new) %>% mutate(Count = "New Borrowers") %>% select(-new.borrowers)

nloans <- mutate(ldf.full, counter = 1)
nloans$week <- as.numeric(strftime(nloans$req.date, format = "%V"))
nloans <- mutate(nloans, exp.week = if_else(week>=42, week-41,week + 11)) %>% group_by(exp.week) %>%
  summarise(num.loans = sum(counter, na.rm=T)) %>% mutate(cum.loans = if_else(exp.week==1,num.loans,as.double(NA)))
for (i in 2:length(nloans$exp.week)){
  nloans$cum.loans[i] <- nloans$cum.loans[i-1] + nloans$num.loans[i]
}
nloans <- rename(nloans, total = cum.loans) %>% mutate(Count = "Loans") %>% select(-num.loans)
nloans <- rbind(nloans, first)

borrow.plot <- ggplot(data = nloans, aes(x = exp.week, y = total, fill = Count, color = Count, 
                                         group = Count)) + geom_point() + geom_line() + 
  labs(x = "Week of Experiment", 
       y = "Cumulative Total") + theme_bw() + 
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) + 
  theme(plot.title = element_text(hjust=0.5)) + theme(legend.position = c(0.2,0.8)) 

ggsave(filename="../Output/cum_totals.png", plot=borrow.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A13: value of time distribution#####
cur.cust <- mutate(cur.cust, total.fees = if_else(HiFee==1 & treated==1, total.borrowed*daily.rate*0.1,
                                                  if_else(HiFee==0 & treated==0, total.borrowed*daily.rate*0.02, as.double(NA))),
                   total.time = num.loans*mm.time,
                   val.time = total.fees/total.time)

valtime.dist <- ggplot(data = cur.cust[which(cur.cust$ever.borrow>0),], aes(val.time)) + 
  geom_histogram(binwidth = 100) + coord_cartesian(xlim = c(0,3000)) + 
  labs(x = "Lower Bound: Value of Time (RWF per Hour)", y = "No. Consumers") + 
  theme_bw() + theme(plot.title = element_text(hjust=0.5)) + 
  theme(legend.background = element_rect(fill="transparent"))

ggsave(filename="../Output/valtime.png", plot=valtime.dist, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

#####Figure A14: dynamic effects on UR#####
ur <- mutate(ur, m1 = if_else(month==1,1,0), m2 = if_else(month==2,1,0), m3 = if_else(month==3,1,0),
             m4 = if_else(month==4,1,0), m5 = if_else(month==5,1,0), m6 = if_else(month==6,1,0), m7 = if_else(month==7,1,0),
             treat = if_else(treatment=="control",0,1))
ur.reg.dyn <- felm(ur ~ treat:m1 + treat:m2 + treat:m4 + treat:m5 + treat:m6 + treat:m7 + bin1.1 + bin1.2 + bin1.3 + 
                     bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                     bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                     bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(ur.reg.dyn, robust = TRUE)

coefs <- ur.reg.dyn$coefficients[25:30]
SEs <- ur.reg.dyn$cse[25:30]
plot.data <- as.data.frame(cbind(coefs, SEs))
plot.data$month <- c(-2, -1, 1, 2, 3 ,4)
plot.data <- mutate(plot.data, CI.High = coefs + 1.96*SEs, CI.Low = coefs - 1.96*SEs)
plot.data <- rbind(plot.data, c(0,0,0, NA, NA))

ur.es.plot <- ggplot(data = plot.data, aes(x = month, y = coefs)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_errorbar(aes(ymin = CI.Low, ymax=CI.High), position = position_dodge(0.6), width = .1) + 
  geom_hline(yintercept = 0, color = "grey") + 
  labs(x = "Dynamic ATE on Solar Demand", y = "") + theme_bw() +  
  theme(legend.position = "none") 

ggsave(filename="../Output/Dynamic_UR.png", plot=ur.es.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)
#####Figure A15: dynamic effects on in-person transactions#####
ntrans.reg.dyn <- felm(ntrans ~ treat:m1 + treat:m2 + treat:m4 + treat:m5 + treat:m6 + treat:m7 + bin1.1 + bin1.2 + bin1.3 + 
                         bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                         bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                         bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(ntrans.reg.dyn, robust = TRUE)

coefs <- ntrans.reg.dyn$coefficients[25:30]
SEs <- ntrans.reg.dyn$cse[25:30]
plot.data <- as.data.frame(cbind(coefs, SEs))
plot.data$month <- c(-2, -1, 1, 2, 3 ,4)
plot.data <- mutate(plot.data, CI.High = coefs + 1.96*SEs, CI.Low = coefs - 1.96*SEs)
plot.data <- rbind(plot.data, c(0,0,0, NA, NA))

ntrans.es.plot <- ggplot(data = plot.data, aes(x = month, y = coefs)) + 
  geom_point(stat = "identity", position = position_dodge(0.6), size = 1) + 
  geom_errorbar(aes(ymin = CI.Low, ymax=CI.High), position = position_dodge(0.6), width = .1) + 
  geom_hline(yintercept = 0, color = "grey") + 
  labs(x = "Dynamic ATE on In-Person Transactions", y = "") + theme_bw() +  
  theme(legend.position = "none")  

ggsave(filename="../Output/Dynamic_NT.png", plot=ntrans.es.plot, device="png",
       height=2.75, width=5.41, units="in", dpi=300, pointsize = 7)

##########################################################################################
#Appendix tables 
##########################################################################################
#####Table A1: balance####
#Pre-experimental outcomes of interest: pre-UR, daily rate, mean and sd wH used prior 
#to the experiment, tenure with the company
ur.bal <- felm(util_90d ~ treated + bin1 + bin2 + bin3|0|0, data = cur.cust)
summary(ur.bal)

dr.bal <- felm(Sum_Daily_Rate ~ treated + bin1 + bin2 + bin3|0|0, 
               data = cur.cust[which(cur.cust$daily.rate<500),])
summary(dr.bal)

mean.wh <- ur %>% filter(month<4) %>% group_by(uniquecustomerid) %>% summarise(mean.wh = mean(wh.out, na.rm=T))
cur.cust <- left_join(cur.cust, mean.wh, by = c("customer.id"="uniquecustomerid"))

wh.bal <- felm(mean.wh ~ treated + bin1 + bin2 + bin3|0|0,data = cur.cust)
summary(wh.bal)

sd.bal <- felm(sd.wh ~ treated + bin1 + bin2 + bin3|0|0, data = cur.cust)
summary(sd.bal)

cur.cust <- mutate(cur.cust, avg.pmt.days = avg.pmt/daily.rate)
pmt.bal <- felm(avg.pmt.days ~ treated + bin1 + bin2 + bin3|0|0, data = cur.cust)
summary(pmt.bal)

tenure.bal <- felm(tenure ~ treated + bin1 + bin2 + bin3|0|0, 
                   data = cur.cust)
summary(tenure.bal)

writeLines(capture.output(stargazer(ur.bal, dr.bal, wh.bal, sd.bal, tenure.bal, pmt.bal, title="Balance Table",
          dep.var.labels=c("90-day Pre UR",
                           "Daily Rate", "Mean wH","SD wH", "Tenure", "Pmt Size"),
          covariate.labels=c("Treated","Stratum 1","Bin 2", "Bin 3"),
          omit.stat=c("LL","ser"), no.space=TRUE)), "../Output/balance.tex")
#####Table A2: borrower characteristics####
ur.enable.2 <- select(ur.enable.2, everything()) %>% group_by(unique_customer_id) %>%
  arrange(calendar_id, .by_group=TRUE) %>% ungroup() %>%
  mutate(lag.id = lag(unique_customer_id, n = 1),
         first = if_else(is.na(lag.id)|lag.id!=unique_customer_id,1,0),
         lag.status = lag(enable_status, n=1),
         switch.off = if_else(enable_status=="disabled" & lag.status=="enabled" & first!=1,1,0),
         switch.on = if_else(enable_status=="enabled" & lag.status=="disabled" & first!=1,1,0),
         days.off = if_else(enable_status=="enabled"|enable_status=="pending_disabled",0,
                            if_else(switch.off==1,1,as.double(NA))))

ur.enable.2 <- mutate(ur.enable.2, month = if_else(calendar_id>=20190714 & calendar_id < 20190814,1,
                                                   if_else(calendar_id>=20190814 & calendar_id < 20190914,2,
                                                           if_else(calendar_id>=20190914 & calendar_id < 20191014,3,
                                                                   if_else(calendar_id>=20191014 & calendar_id < 20191114,4,
                                                                           if_else(calendar_id>=20191114 & calendar_id < 20191214,5,
                                                                                   if_else(calendar_id>=20191214 & calendar_id < 20200114,6,
                                                                                           if_else(calendar_id>=20200114 & calendar_id < 20200214,7,as.double(NA)))))))))

monthly.off <- filter(ur.enable.2, !is.na(month)) %>% group_by(unique_customer_id, month) %>%
  summarise(times.off = sum(switch.off, na.rm=T))

ur <- left_join(ur, monthly.off, by = c("uniquecustomerid" = "unique_customer_id", "month"))
status.stats <- filter(ur.enable.2, month < 4 & !is.na(month)) %>% group_by(unique_customer_id) %>%
  summarise(times.off = sum(switch.off, na.rm=T))

cur.cust <- left_join(cur.cust, status.stats, by = c("customer.id" = "unique_customer_id"))

tu.desc1 <- felm(ever.borrow ~ as.factor(treatment)|0|0, 
                 data = cur.cust[which(cur.cust$treated==1),])
summary(tu.desc1, robust = TRUE)

tu.desc <- felm(ever.borrow ~ as.factor(treatment) + util_90d + daily.rate + tenure + 
                  avg.pmt.days + times.off |0|0,
                data = cur.cust[which(cur.cust$treated==1),])
summary(tu.desc, robust = TRUE)

tu.desc2 <- felm(ever.borrow ~ as.factor(treatment) + util_90d + daily.rate + tenure + 
                   avg.pmt.days + times.off + mean.wh + sd.wh + mm.time|0|0,
                 data = cur.cust[which(cur.cust$treated==1),])
summary(tu.desc2, robust = TRUE)

# Create a table
table <- matrix(NA, nrow=34, ncol=4)

table[1,] <- c(" ","(1)", "(2)","(3)")
table[2,] <- unlist(c("7 days, 2\\%", round(tu.desc1$coefficients[8],3), 
                      round(tu.desc$coefficients[13],3),round(tu.desc2$coefficients[13],3)))
table[3,] <- c("",paste0("(",round(tu.desc1$rse[8],3),")"), 
               paste0("(",round(tu.desc$rse[13],3),")"),paste0("(",round(tu.desc2$rse[13],3),")"))
table[4,] <- unlist(c("7 days, 10\\%", round(tu.desc1$coefficients[7],3), 
                      round(tu.desc$coefficients[12],3),round(tu.desc2$coefficients[12],3)))
table[5,] <- c("",paste0("(",round(tu.desc1$rse[7],3),")"), 
               paste0("(",round(tu.desc$rse[12],3),")"), paste0("(",round(tu.desc2$rse[12],3),")"))
table[6,] <- unlist(c("14 days, 2\\%", round(tu.desc1$coefficients[6],3), 
                      round(tu.desc$coefficients[11],3), round(tu.desc2$coefficients[11],3)))
table[7,] <- c("",paste0("(",round(tu.desc1$rse[6],3),")"), 
               paste0("(",round(tu.desc$rse[11],3),")"), paste0("(",round(tu.desc2$rse[11],3),")"))
table[8,] <- unlist(c("14 days, 10\\%", round(tu.desc1$coefficients[5],3), 
                      round(tu.desc$coefficients[10],3), round(tu.desc2$coefficients[10],3)))
table[9,] <- c("",paste0("(",round(tu.desc1$rse[5],3),")"), 
               paste0("(",round(tu.desc$rse[10],3),")"), paste0("(",round(tu.desc2$rse[10],3),")"))
table[10,] <- unlist(c("7 days, 2\\%, Time Limit", round(tu.desc1$coefficients[4],3), 
                       round(tu.desc$coefficients[9],3), round(tu.desc2$coefficients[9],3)))
table[11,] <- c("",paste0("(",round(tu.desc1$rse[4],3),")"), 
                paste0("(",round(tu.desc$rse[9],3),")"), paste0("(",round(tu.desc2$rse[9],3),")"))
table[12,] <- unlist(c("7 days, 10\\%, Time Limit", round(tu.desc1$coefficients[3],3), 
                       round(tu.desc$coefficients[8],3), round(tu.desc2$coefficients[8],3)))
table[13,] <- c("",paste0("(",round(tu.desc1$rse[3],3),")"), 
                paste0("(",round(tu.desc$rse[8],3),")"), paste0("(",round(tu.desc2$rse[8],3),")"))
table[14,] <- unlist(c("14 days, 2\\%, Time Limit", round(tu.desc1$coefficients[2],3), 
                       round(tu.desc$coefficients[7],3), round(tu.desc2$coefficients[7],3)))
table[15,] <- c("",paste0("(",round(tu.desc1$rse[2],3),")"), 
                paste0("(",round(tu.desc$rse[7],3),")"), paste0("(",round(tu.desc2$rse[7],3),")"))
table[16,] <- unlist(c("Pre-Experimental Demand", "", round(tu.desc$coefficients[9],3),
                       round(tu.desc2$coefficients[9],3)))
table[17,] <- c("","", paste0("(",round(tu.desc$rse[9],3),")"),paste0("(",round(tu.desc2$rse[9],3),")"))
table[18,] <- unlist(c("Daily Rate", "", round(tu.desc$coefficients[10],4), 
                       round(tu.desc2$coefficients[10],4)))
table[19,] <- c("","", paste0("(",round(tu.desc$rse[10],4),")"), paste0("(",round(tu.desc2$rse[10],4),")"))
table[20,] <- unlist(c("Tenure", "", round(tu.desc$coefficients[11],4), round(tu.desc2$coefficients[11],4)))
table[21,] <- c("","", paste0("(",round(tu.desc$rse[11],4),")"), paste0("(",round(tu.desc2$rse[11],4),")"))
table[22,] <- unlist(c("Mean Transaction Size", "", round(tu.desc$coefficients[12],4),
                       round(tu.desc2$coefficients[12],4)))
table[23,] <- c("","", paste0("(",round(tu.desc$rse[12],4),")"), paste0("(",round(tu.desc2$rse[12],4),")"))
table[24,] <- unlist(c("Mean Switch Offs", "", round(tu.desc$coefficients[13],3),
                       round(tu.desc2$coefficients[13],3)))
table[25,] <- c("","", paste0("(",round(tu.desc$rse[13],3),")"), paste0("(",round(tu.desc2$rse[13],3),")"))
table[26,] <- unlist(c("Mean Use (wH)", "", "", round(tu.desc2$coefficients[14],3)))
table[27,] <- c("","", "", paste0("(",round(tu.desc2$rse[14],3),")"))
table[28,] <- unlist(c("SD(Use) (wH)", "", "", round(tu.desc2$coefficients[15],3)))
table[29,] <- c("","", "", paste0("(",round(tu.desc2$rse[15],3),")"))
table[30,] <- unlist(c("Time to MM Agent", "","", round(tu.desc2$coefficients[16],3)))
table[31,] <- c("","","", paste0("(",round(tu.desc2$rse[16],3),")"))
table[32,] <- unlist(c("Constant", round(tu.desc1$coefficients[1],3), round(tu.desc$coefficients[1],3), 
                       round(tu.desc2$coefficients[1],3)))
table[33,] <- c("",paste0("(",round(tu.desc1$rse[1],3),")"), paste0("(",round(tu.desc$rse[1],3),")"), 
                paste0("(",round(tu.desc2$rse[1],3),")"))
table[34,] <- unlist(c("N",tu.desc1$N, tu.desc$N, tu.desc2$N))

myxtable <- xtable(table)

align(myxtable) <- c("l","p{5cm}",rep(">{\\centering\\arraybackslash}p{2.8cm}",3))

caption(myxtable) <- "Borrower Characteristics"

label(myxtable) <- "tabTUdesc"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=F,include.rownames=F,table.placement="H",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0,0,1,33,nrow(table)),
        command = c(
          paste0("\\toprule"),
          " & \\multicolumn{2}{l}{\\textit{Dependent variable:} Ever Borrow} \\\\",
          " \\midrule ",
          " \\midrule ",
          "\\bottomrule \\multicolumn{4}{l}{\\multirow{2}{14cm}{\\small Notes: Pre-experimental demand is the proportion of time each month a consumer has access to solar. Daily rate is the price the consumer pays for a day of solar in RWF, where higher prices correspond to larger systems that support more appliances. Tenure is the number of months since adoption. Mean transaction size is the average transaction size in days (e.g., normalized by the daily rate). Mean switch offs is the average number of times a consumer is remotely locked out of their system in a month. Mean use and SD(Use) are the mean and standard deviation of watt hours used on days when the system is switched on. Time to MM agent is the self-reported time it takes a consumer to reach the nearest mobile money agent. I report robust standard errors in parentheses.}} \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ "
        )),
      type = "latex",file="../Output/tu_desc_updated.tex")
#####Table A3: Robustness of to other specifications#####
#Pooled
ur.reg.xs <- felm(ur ~ treated + bin1 + bin2 + bin3 |0|0|id, data = ur[which(ur$month>=4),])
summary(ur.reg.xs, robust = TRUE)

ur.reg.ancova <- felm(ur ~ treated + bin1 + bin2 + bin3 + util_90d |0|0|id, data = ur[which(ur$month>=4),])
summary(ur.reg.ancova, robust = TRUE)

ntrans.reg.xs <- felm(ntrans ~ treated + bin1 + bin2 + bin3 |0|0|id, data = ur[which(ur$month>=4),])
summary(ntrans.reg.xs, robust = TRUE)

ntrans.reg.ancova <- felm(ntrans ~ treated + bin1 + bin2 + bin3 + util_90d |0|0|id, data = ur[which(ur$month>=4),])
summary(ntrans.reg.ancova, robust = TRUE)

table <- matrix(NA, nrow=6, ncol=7)

table[1,] <- c(" ","(1)","(2)","(3)","(4)","(5)","(6)")
table[2,] <- c("","DiD","Cross Section","ANCOVA","DiD","Cross Section","ANCOVA")
table[3,] <- unlist(c("Treated", round(ur.reg$coefficients[1],4), round(ur.reg.xs$coefficients[2],4), round(ur.reg.ancova$coefficients[2],4),
                      round(nt.reg$coefficients[1],4), round(ntrans.reg.xs$coefficients[2],4), round(ntrans.reg.ancova$coefficients[2],4)))
table[4,] <- c("", paste0("(",round(ur.reg$cse[1],4),")"), paste0("(",round(ur.reg.xs$cse[2],4),")"), paste0("(",round(ur.reg.ancova$cse[2],4),")"),
               paste0("(",round(nt.reg$cse[1],4),")"), paste0("(",round(ntrans.reg.xs$cse[2],4),")"), paste0("(",round(ntrans.reg.ancova$cse[2],4),")"))
table[5,] <- c("Control Mean", rep(round(cmeans(outcome = "ur")[1,1]),3), 
               rep(round(cmeans(outcome = "nt")[1,1]),3))
table[6,] <- unlist(c("N",ur.reg$N, ur.reg.xs$N, ur.reg.ancova$N, nt.reg$N,
                      ntrans.reg.xs$N, ntrans.reg.ancova$N))

myxtable <- xtable(table)

align(myxtable) <- c("l","p{3cm}", "p{2cm}", "p{2cm}", "p{2cm}", "p{2cm}", "p{2cm}", "p{2cm}")

caption(myxtable) <- "Robustness to Alternative Specifications"

label(myxtable) <- "robustness"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=F,include.rownames=F,table.placement="H",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 0, 2, 4, nrow(table)),
        command = c(
          paste0("\\toprule"),
          " & \\multicolumn{3}{c}{\\textit{Utilization Rate}} & \\multicolumn{3}{c}{\\textit{No. In-Person Transactions}}\\\\",
          " \\midrule ",
          " \\midrule ", 
          "\\bottomrule \\multicolumn{7}{l}{\\multirow{2}{16cm}{\\small Notes: Average treatment effects on demand for solar and the number of in-person transactions, pooling across all strata and all cross-randomized treatments. DiD denotes the difference in difference specification, which includes individual fixed effects and strata by month fixed effects. Cross-sectional denotes a regression comparing the treatment to the control group using only treatment months, controlling only for strata fixed effects. ANCOVA denotes the cross sectional regression with an additional control for pre-experimental demand. Parentheses show standard errors clustered at the individual level.}} \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ "
        )),
      type = "latex",file="../Output/robustness.tex")

#####Table A4: ATEs using alternative measure of demand#####
ur <- mutate(ur, cont = if_else(ur==1,1,0))

cont.reg <- felm(cont ~ treated + bin1.1 + bin1.2 + bin1.3 + 
                   bin1.4 + bin1.5 + bin1.6 + bin2.1 + bin2.2 + bin2.3 + bin2.4 + bin2.5 + bin2.6 + 
                   bin3.1 + bin3.2 + bin3.3 + bin3.4 + bin3.5 + bin3.6 + 
                   bin4.1 + bin4.2 + bin4.3 + bin4.4 + bin4.5 + bin4.6 |id|0|id, data = ur)
summary(cont.reg, robust = TRUE)

cont.reg.xs <- felm(cont ~ treated + bin1 + bin2 + bin3 |0|0|id, data = ur[which(ur$month>=4),])
summary(cont.reg.xs, robust = TRUE)

cont.reg.ancova <- felm(cont ~ treated + bin1 + bin2 + bin3 + util_90d |0|0|id, data = ur[which(ur$month>=4),])
summary(cont.reg.ancova, robust = TRUE)

table <- matrix(NA, nrow=5, ncol=4)

table[1,] <- c(" ","(1)","(2)","(3)")
table[2,] <- c("","DiD","Cross Section","ANCOVA")
table[3,] <- unlist(c("Treated", round(cont.reg$coefficients[1],4), 
                      round(cont.reg.xs$coefficients[2],4), 
                      round(cont.reg.ancova$coefficients[2],4)))
table[4,] <- c("", paste0("(",round(cont.reg$cse[1],4),")"), 
               paste0("(",round(cont.reg.xs$cse[2],4),")"), 
               paste0("(",round(cont.reg.ancova$cse[2],4),")"))
table[5,] <- unlist(c("N",cont.reg$N, cont.reg.xs$N, cont.reg.ancova$N))

myxtable <- xtable(table)

align(myxtable) <- c("l","p{3cm}", "p{2cm}", "p{2cm}", "p{2cm}")

caption(myxtable) <- "Robustness to Alternative Measure of Demand"

label(myxtable) <- "robustnessDemand"

print(myxtable, floating = TRUE, caption.placement="top",sanitize.text.function = identity,
      include.colnames=F,include.rownames=F,table.placement="H",
      hline.after=NULL,
      add.to.row=list(
        pos = list(0, 2, 4, nrow(table)),
        command = c(
          paste0("\\toprule"),
          " \\midrule ",
          " \\midrule ", 
          "\\bottomrule \\multicolumn{4}{l}{\\multirow{2}{10cm}{\\small Notes: Average treatment effects on the likelihood of having continuous access to electricity in a month, pooling across all strata and all cross-randomized treatments. DiD denotes the difference in difference specification, which includes individual fixed effects and strata by month fixed effects. Cross-sectional denotes a regression comparing the treatment to the control group using only treatment months, controlling only for strata fixed effects. ANCOVA denotes the cross sectional regression with an additional control for pre-experimental demand. Parentheses show standard errors clustered at the individual level.}} \\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ "
        )),
      type = "latex",file="../Output/robustnessDemand.tex")


